@@ -278,6 +278,13 @@ class Share(BASE, ManilaBase):
         viewonly=True,
         join_depth=2,
     )
+    share_type = orm.relationship(
+        "ShareTypes",
+        lazy=True,
+        foreign_keys=share_type_id,
+        primaryjoin='and_('
+                    'Share.share_type_id == ShareTypes.id, '
+                    'ShareTypes.deleted == "False")')
 
 
 class ShareInstance(BASE, ManilaBase):
@@ -365,13 +372,6 @@ class ShareTypes(BASE, ManilaBase):
     deleted = Column(String(36), default='False')
     name = Column(String(255))
     is_public = Column(Boolean, default=True)
-    shares = orm.relationship(Share,
-                              backref=orm.backref('share_type',
-                                                  uselist=False),
-                              foreign_keys=id,
-                              primaryjoin='and_('
-                              'Share.share_type_id == ShareTypes.id, '
-                              'ShareTypes.deleted == "False")')
 
 
 class ShareTypeProjects(BASE, ManilaBase):
