@@ -62,6 +62,7 @@ import manila.share.drivers.hdfs.hdfs_native
 import manila.share.drivers.hitachi.hds_hnas
 import manila.share.drivers.hp.hp_3par_driver
 import manila.share.drivers.huawei.huawei_nas
+import manila.share.drivers.ibm.gpfs
 import manila.share.drivers.netapp.options
 import manila.share.drivers.quobyte.quobyte
 import manila.share.drivers.service_instance
@@ -123,6 +124,7 @@ _global_opt_lists = [
     manila.share.drivers.hitachi.hds_hnas.hds_hnas_opts,
     manila.share.drivers.hp.hp_3par_driver.HP3PAR_OPTS,
     manila.share.drivers.huawei.huawei_nas.huawei_opts,
+    manila.share.drivers.ibm.gpfs.gpfs_share_opts,
     manila.share.drivers.netapp.options.netapp_proxy_opts,
     manila.share.drivers.netapp.options.netapp_connection_opts,
     manila.share.drivers.netapp.options.netapp_transport_opts,
