@@ -286,9 +286,8 @@ class HP3ParShareDriver(driver.ShareDriver):
             share['id'],
             protocol,
             extra_specs,
-            snapshot['share']['project_id'],
-            snapshot['share']['id'],
-            snapshot['share']['share_proto'],
+            share['project_id'],
+            snapshot['share_id'],
             snapshot['id'],
             self.fpg,
             self.vfs,
